sphinxcontrib_serializinghtml: Sphinx extension which outputs serialized HTML files
===================================================================================

Description
-----------

Sphinx extension which outputs serialized HTML files

License
-------

BSD
